# Re: \[PATCH RESEND 1/3\] initramfs: move unnecessary memcmp from hot path

- From: Al Viro \<viro@zeniv.linux.org.uk\>
- Date: 2021-08-04 12:59:32 
- List: linux-doc
- Page: https://ratatoskr.run/linux-doc/2021/08/211605
- Thread: https://ratatoskr.run/linux-fsdevel/2021/07/210702/t.md

```text
On Wed, Aug 04, 2021 at 11:31:29AM +0200, David Disseldorp wrote:
> Ping, any feedback on this change?
> 
> I think it's a no brainer, but for kicks I ran a few unrealistic micro
> benchmarks on my laptop. Extraction time for a cpio image with 1M+
> directories improved by 5ms (pre: 14.614s, post: 14.609s), when averaged
> across 20 runs of:
>   qemu-system-x86_64 -machine accel=kvm -smp cpus=1 -m 10240 \
>         -kernel ~/linux/arch/x86/boot/bzImage \
>         -initrd ./initrds/gen_cpio.out \
>         -append "initramfs_async=0 console=ttyS0 panic=0" -nographic \
>         | awk '/Trying to unpack rootfs/ {start_ts = $2};
>                /Freeing initrd memory/ {end_ts = $2}
>                END {printf "%f\n", end_ts - start_ts}'

What was the dispersion for those runs?
```
